document.addEventListener('DOMContentLoaded', () => {
  const homeTeamSelect = document.getElementById('home-team');
  const awayTeamSelect = document.getElementById('away-team');
  const simulateBtn = document.getElementById('simulate-btn');
  const matchEvents = document.getElementById('match-events');
  const homeScore = document.querySelector('.home-team .team-score');
  const awayScore = document.querySelector('.away-team .team-score');

  const events = [
    "GOAL! Beautiful strike!",
    "Yellow card for a rough tackle",
    "Close chance! Hit the post!",
    "Great save by the goalkeeper!",
    "Corner kick awarded",
    "Dangerous free kick opportunity"
  ];

  simulateBtn.addEventListener('click', () => {
    if (!homeTeamSelect.value || !awayTeamSelect.value) {
      alert('Please select both teams');
      return;
    }

    if (homeTeamSelect.value === awayTeamSelect.value) {
      alert('Please select different teams');
      return;
    }

    // Reset scores
    let homeGoals = 0;
    let awayGoals = 0;
    matchEvents.innerHTML = '';

    // Simulate 90 minutes
    for (let minute = 1; minute <= 90; minute++) {
      if (Math.random() < 0.1) { // 10% chance of event
        const event = events[Math.floor(Math.random() * events.length)];
        if (event.includes('GOAL')) {
          if (Math.random() < 0.5) {
            homeGoals++;
          } else {
            awayGoals++;
          }
        }
        
        matchEvents.innerHTML += `
          <p><strong>${minute}'</strong> ${event}</p>
        `;
      }
    }

    // Update scores
    homeScore.textContent = homeGoals;
    awayScore.textContent = awayGoals;

    // Animate the score change
    homeScore.style.animation = 'scoreUpdate 0.5s ease';
    awayScore.style.animation = 'scoreUpdate 0.5s ease';

    // Remove animation class after animation ends
    setTimeout(() => {
      homeScore.style.animation = '';
      awayScore.style.animation = '';
    }, 500);
  });

  // Prevent same team selection
  homeTeamSelect.addEventListener('change', () => {
    Array.from(awayTeamSelect.options).forEach(option => {
      option.disabled = option.value === homeTeamSelect.value;
    });
  });

  awayTeamSelect.addEventListener('change', () => {
    Array.from(homeTeamSelect.options).forEach(option => {
      option.disabled = option.value === awayTeamSelect.value;
    });
  });
});
